teamCommand = Turbine.ShellCommand();

-- Execute command --
function teamCommand:Execute(cmd, args)
	-- Check if command has arguments --
	if string.len(args) < 1 then toggleVisibility(not mainWindow:IsVisible()); return; end

	-- Turn arguments to lower case characters --
	args = string.lower(args);

	-- Display command help message --
	if string.find(args, translate("command_help", clientLanguage)) == 1 then notification(translate("command_arguments", settings["language"])); return; end

	-- Toggle visibility --
	if string.find(args, translate("command_show", clientLanguage)) == 1 then toggleVisibility(true); return; end
	if string.find(args, translate("command_hide", clientLanguage)) == 1 then toggleVisibility(false); return; end
	if string.find(args, translate("command_toggle", clientLanguage)) == 1 then toggleVisibility(not mainWindow:IsVisible()); return; end

	-- Save group --
	if string.find(args, translate("command_save", clientLanguage)) == 1 then saveGroupCommand(string.match(args, translate("command_save", clientLanguage) .. "(%a+)")); return; end

	-- Load group --
	if string.find(args, translate("command_load", clientLanguage)) == 1 then loadGroupCommand(string.match(args, translate("command_load", clientLanguage) .. "(%a+)")); return; end

	-- Clear window --
	if string.find(args, translate("command_clear", clientLanguage)) == 1 then clearWindowCommand(); return; end

	-- Unknown command argument --
	notification(rgb["error"] .. translate("command_unknown", clientLanguage) .. rgb["clear"]);
end

-- Toggle visibility of the main window --
function toggleVisibility(state)
	mainWindow:SetVisible(state);
end

-- Save group --
function saveGroupCommand(name)
	-- Return error if there is no group to save --
	if getLenght(groupMembers) < 1 then
		notification(rgb["error"] .. translate("nothingToSave", settings["language"]) .. rgb["clear"]);
		errorMessage(translate("nothingToSave", settings["language"]))
		return;
	end

	-- Save group --
	saveData(Turbine.DataScope.Server, "TeamOrganizer_CustomData_" .. name, groupMembers);
	notification(translate("groupSaved", settings["language"]) .. " " .. name);
end

-- Load group --
function loadGroupCommand(name)
	saveData(Turbine.DataScope.Server, "TeamOrganizer_LoadRequest", name);
	reloadPlugin();
end

-- Clear Team Organizer window --
function clearWindowCommand(name)
	saveData(Turbine.DataScope.Server, "TeamOrganizer_LoadRequest", "Clear Groups");
	saveData(Turbine.DataScope.Server, "TeamOrganizer_GroupMembers", nil);
	reloadPlugin();
end


-- Commands --
Turbine.Shell.AddCommand("team", teamCommand);
Turbine.Shell.AddCommand("teamorganizer", teamCommand);