-- Save Data --
function saveData(dataScope, key, value)
	Turbine.PluginData.Save(dataScope, key, value);
end

-- Load group information --
function loadGroup()
	-- Check if player have given a load request --
	loadRequest = Turbine.PluginData.Load(Turbine.DataScope.Server, "TeamOrganizer_LoadRequest");

	-- Reset load Request --
	saveData(Turbine.DataScope.Server, "TeamOrganizer_LoadRequest", nil);

	-- Return the previous group player played with --
	if loadRequest == "Previous Group" then
		return Turbine.PluginData.Load(Turbine.DataScope.Server, "TeamOrganizer_GroupMembers");
	end

	-- Return nothing since we want to clear the window --
	if loadRequest == "Clear Groups" then
		return nil;
	end

	-- If load request was found load the team being requested --
	if loadRequest ~= nil then
		-- Load the requested group --
		local _groupMembers = Turbine.PluginData.Load(Turbine.DataScope.Server, "TeamOrganizer_CustomData_" .. loadRequest);

		-- See if requested group exists --
		if _groupMembers ~= nil then
			-- Group loaded successfully --
			notification(translate("groupLoaded", settings["language"]) .. " " .. loadRequest);
			saveData(Turbine.DataScope.Server, "TeamOrganizer_GroupMembers", _groupMembers);
			return _groupMembers;
		else
			-- Failed to load group --
			notification(rgb["error"] .. translate("groupLoadedFailed", settings["language"]) .. " " .. loadRequest .. rgb["clear"]);
			errorMessage(translate("groupLoadedFailedError", settings["language"]));
			return Turbine.PluginData.Load(Turbine.DataScope.Server, "TeamOrganizer_GroupMembers");
		end
	end

	-- If load request is empty get previous group player played with --
	if loadRequest == nil then
		return Turbine.PluginData.Load(Turbine.DataScope.Server, "TeamOrganizer_GroupMembers");
	end

	-- If all fails return nothing --
	return nil;
end


-- Load Settings --
function loadSettings()
	-- Load window position
	local _windowPosition = Turbine.PluginData.Load(Turbine.DataScope.Character, "TeamOrganizer_WindowPosition");
	if _windowPosition ~= nil then windowPosition = _windowPosition; end

	-- Load settings --
	local _settings = Turbine.PluginData.Load(Turbine.DataScope.Server, "TeamOrganizer_Settings");
	if _settings ~= nil then settings = _settings; end

	-- Load customization settings --
	local _customization = Turbine.PluginData.Load(Turbine.DataScope.Server, "TeamOrganizer_customization");
	if _customization ~= nil then
		playerNameColor = {
			inParty = Turbine.UI.Color(tonumber(_customization["inParty"]["red"]), tonumber(_customization["inParty"]["green"]), tonumber(_customization["inParty"]["blue"])),
			notInParty= Turbine.UI.Color(tonumber(_customization["notInParty"]["red"]), tonumber(_customization["notInParty"]["green"]), tonumber(_customization["notInParty"]["blue"])),
			invited  = Turbine.UI.Color(tonumber(_customization["invited"]["red"]), tonumber(_customization["invited"]["green"]), tonumber(_customization["invited"]["blue"])),
			declined = Turbine.UI.Color(tonumber(_customization["declined"]["red"]), tonumber(_customization["declined"]["green"]), tonumber(_customization["declined"]["blue"])),
			anotherGroup = Turbine.UI.Color(tonumber(_customization["anotherGroup"]["red"]), tonumber(_customization["anotherGroup"]["green"]), tonumber(_customization["anotherGroup"]["blue"])),
			offline = Turbine.UI.Color(tonumber(_customization["offline"]["red"]), tonumber(_customization["offline"]["green"]), tonumber(_customization["offline"]["blue"]))
		}
	end
end

-- Load settings --
loadSettings();