-- Build layout for customization options --
function createCustomizationOption(parent, xPos, yPos, name, tooltipText, keyValue)
	local label = Turbine.UI.Label();
	label:SetParent(parent);
	label:SetForeColor(Scripts.color["golden"]);
	label:SetFont(Turbine.UI.Lotro.Font.TrajanPro15);
	label:SetText(name);
	label:SetSize(240, 30);
	label:SetPosition(xPos, yPos);
	local labelTooltipHolder = Turbine.UI.Label();
	labelTooltipHolder:SetParent(parent);
	labelTooltipHolder:SetSize(60, 30);
	labelTooltipHolder:SetPosition(xPos, yPos);
	TooltipAttach(labelTooltipHolder, tooltipText);


	local name = Turbine.UI.Label();
	name:SetParent(parent);
	name:SetSize(100, 30);
	name:SetPosition(xPos, yPos + 20);
	name:SetFont(Turbine.UI.Lotro.Font.Verdana16);
	name:SetForeColor(Scripts.playerNameColor[keyValue]);
	name:SetText(Scripts.translate("username", Scripts.settings["language"]));


	local redBox = Turbine.UI.Lotro.TextBox();
	redBox:SetParent(parent);
	redBox:SetSize(32, 18);
	redBox:SetFont(Turbine.UI.Lotro.Font.Verdana12);
	redBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	redBox:SetMultiline(false);
	redBox:SetText(math.floor(name:GetForeColor().R * 255));
	redBox:SetPosition(xPos + 90, yPos + 20);
	local redBoxLabel = Turbine.UI.Label();
	redBoxLabel:SetParent(parent);
	redBoxLabel:SetSize(10, 20);
	redBoxLabel:SetPosition(xPos + 80, yPos + 20);
	redBoxLabel:SetFont(Turbine.UI.Lotro.Font.Verdana16);
	redBoxLabel:SetForeColor(Scripts.color["red"]);
	redBoxLabel:SetText("R");


	local greenBox = Turbine.UI.Lotro.TextBox();
	greenBox:SetParent(parent);
	greenBox:SetSize(32, 18);
	greenBox:SetFont(Turbine.UI.Lotro.Font.Verdana12);
	greenBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	greenBox:SetMultiline(false);
	greenBox:SetText(math.floor(name:GetForeColor().G * 255));
	greenBox:SetPosition(xPos + 140, yPos + 20);
	local greenBoxLabel = Turbine.UI.Label();
	greenBoxLabel:SetParent(parent);
	greenBoxLabel:SetSize(10, 20);
	greenBoxLabel:SetPosition(xPos + 130, yPos + 20);
	greenBoxLabel:SetFont(Turbine.UI.Lotro.Font.Verdana16);
	greenBoxLabel:SetForeColor(Scripts.color["green"]);
	greenBoxLabel:SetText("G");


	local blueBox = Turbine.UI.Lotro.TextBox();
	blueBox:SetParent(parent);
	blueBox:SetSize(32, 18);
	blueBox:SetFont(Turbine.UI.Lotro.Font.Verdana12);
	blueBox:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	blueBox:SetMultiline(false);
	blueBox:SetText(math.floor(name:GetForeColor().B * 255));
	blueBox:SetPosition(xPos + 190, yPos + 20);
	local blueBoxLabel = Turbine.UI.Label();
	blueBoxLabel:SetParent(parent);
	blueBoxLabel:SetSize(10, 20);
	blueBoxLabel:SetPosition(xPos + 180, yPos + 20);
	blueBoxLabel:SetFont(Turbine.UI.Lotro.Font.Verdana16);
	blueBoxLabel:SetForeColor(Scripts.color["blue"]);
	blueBoxLabel:SetText("B");


	local applyButton = Turbine.UI.Lotro.Button();
	applyButton:SetText(Scripts.translate("apply", Scripts.settings["language"]));
	applyButton:SetParent(parent);
	applyButton:SetSize(75, 30);
	applyButton:SetPosition(xPos + 240, yPos + 20);
	applyButton.Click = function( sender, args)
		-- Change Username placeholder to match color given by the user --
		local red = tonumber(redBox:GetText());
		local green = tonumber(greenBox:GetText());
		local blue = tonumber(blueBox:GetText());

		if red == nil then red = 0; end
		if green == nil then green = 0; end
		if blue == nil then blue = 0; end

		if red < 0 then red = 0; end
		if green < 0 then green = 0; end
		if blue < 0 then blue = 0; end

		if red > 255 then red = 255; end
		if green > 255 then green = 255; end
		if blue > 255 then blue = 255; end

		name:SetForeColor(Turbine.UI.Color(red/255, green/255, blue/255));
		redBox:SetText(tostring(red));
		greenBox:SetText(tostring(green));
		blueBox:SetText(tostring(blue));
	end


	local revertButton = Turbine.UI.Lotro.Button();
	revertButton:SetText(Scripts.translate("revert", Scripts.settings["language"]));
	revertButton:SetParent(parent);
	revertButton:SetSize(75, 30);
	revertButton:SetPosition(xPos + 320, yPos + 20);
	revertButton.Click = function( sender, args)
		-- Revert color back to what it was when plugin was loaded --
		name:SetForeColor(Scripts.playerNameColor[keyValue]);
		redBox:SetText(math.floor(name:GetForeColor().R * 255));
		greenBox:SetText(math.floor(name:GetForeColor().G * 255));
		blueBox:SetText(math.floor(name:GetForeColor().B * 255));
	end


	local defaultButton = Turbine.UI.Lotro.Button();
	defaultButton:SetText(Scripts.translate("default", Scripts.settings["language"]));
	defaultButton:SetParent(parent);
	defaultButton:SetSize(75, 30);
	defaultButton:SetPosition(xPos + 400, yPos + 20);
	defaultButton.Click = function( sender, args)
		-- Reset color to default settings --
		name:SetForeColor(Scripts.defaultPlayerNameColor[keyValue]);
		redBox:SetText(math.floor(name:GetForeColor().R * 255));
		greenBox:SetText(math.floor(name:GetForeColor().G * 255));
		blueBox:SetText(math.floor(name:GetForeColor().B * 255));
	end

	-- Return created objects --
	data = {}
	data["label"] = label;
	data["name"] = name;
	data["redBox"] = redBox;
	data["redBoxLabel"] = redBoxLabel;
	data["greenBox"] = greenBox;
	data["greenBoxLabel"] = greenBoxLabel;
	data["blueBox"] = blueBox;
	data["blueBoxLabel"] = blueBoxLabel;
	data["applyButton"] = applyButton;
	data["revertButton"] = revertButton;
	data["defaultButton"] = defaultButton;
	return data;
end
